@@ -15,13 +15,16 @@
 # limitations under the License.
 #
 ##############################################################################
+
+
 import logging
 import subprocess
 import time
 from collections import deque
-
+import shlex
 import util
-
+import types
+import os
 
 class ServerLayer(object):
 
@@ -38,15 +41,14 @@ class ServerLayer(object):
             host, port = server.split(':')
             self.servers.append((host, int(port)))
 
-    def start(self):
-        raise NotImplementedError
-
     def start(self):
         assert self.start_cmd, 'No start command defined'
-        logging.info('Starting server %r', self.start_cmd)
-        return subprocess.Popen(self.start_cmd,
-                                shell=True,
-                                stderr=subprocess.PIPE)
+        if type(self.start_cmd) in types.StringTypes:
+            cmd = shlex.split(self.start_cmd)
+        else:
+            cmd = self.start_cmd
+        logging.info('Starting server %r', cmd)
+        return subprocess.Popen(cmd)
 
     def stop(self):
         self.process.kill()
@@ -68,6 +70,7 @@ class ServerLayer(object):
             else:
                 logging.info('Server up %s:%s', *server)
 
+
     def tearDown(self):
         self.stop()
         to_stop = deque(self.servers)
